@@ -27,8 +27,9 @@ LoginDialog::LoginDialog(bool firstTime, eWallet *paTarget): QWidget((QWidget*)p
 	label = new QLineEdit("", this);
 	label->setContextMenuPolicy(Qt::NoContextMenu);
 	label->setEchoMode(QLineEdit::Password); //EchoOnEdit);
+	label->setInputMethodHints(Qt::ImhHiddenText | Qt::ImhNoAutoUppercase | Qt::ImhNoPredictiveText);
 	//label->setFocus(Qt::TabFocusReason);
-	label->setMaxLength(16);
+	label->setMaxLength(16); //  |
 	//label->setAlignment(Qt::AlignCenter);
 
 	for (int i = 0; i < 12; i++) {
