@@ -13,9 +13,11 @@
  * TODO sort after insert new card
  * TODO add warn message when import and export!
  * TODO multilanguage
- * TODO groups implementation
  * TODO pc version?
  * TODO fix export and import to add field type
+ * TODO fix problems with key
+ * TODO remove/rename groupNames
+ * TODO after insert first group, groups list is not refreshed
  */
 
 #include "eWallet.h"
@@ -211,9 +213,13 @@ void eWallet::selectItem(QListWidgetItem * item) {
 			fnListWidget->setCurrentItem(item);
 		}
 
-		QString target = grouplist.at(fnListWidget->currentRow());
-		//isShowGroups = 2;
-		//backButton->show();
+		QString target;
+
+		if (fnListWidget->currentRow() > 0)
+			target = grouplist.at(fnListWidget->currentRow() - 1);
+		else
+			target = "";
+
 		if (extraWindow.isNull()) {
 			extraWindow = new eWallet(target, this, this);
 			//extraWindow->setAttribute(Qt::WA_Maemo5StackedWindow);
@@ -376,7 +382,7 @@ bool eWallet::openDataBase (QString pas)
 			grouplist.clear ();
 			grouplist = ::dbManager->getGroups ();
 
-			if (grouplist.size() > 1)
+			if (grouplist.size() >= 1)
 				isShowGroups = 1;
 			else
 				isShowGroups = 2;
@@ -563,6 +569,10 @@ void eWallet::showGroups(bool reset)
 	//fnListWidget->setIconSize (QSize (SMALL_WIDTH, SMALL_HEIGH));
 	//fnListWidget->setContentsMargins(10, 1, 0, 1);
 
+	QListWidgetItem* listitem = new QListWidgetItem("<All>", fnListWidget);
+	//listitem->set(target->getSummary());
+	fnListWidget->addItem(listitem);
+
 	for (int i = 0; i < grouplist.size (); i++) {
 		QString target = grouplist.at(i);
 
